==> haskell-adjunctions-4.3-24-i686.pkg.tar.xz: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.3
id: adjunctions-4.3-JgRDCfAwfZHGzcwRn0jHXd
key: adjunctions-4.3-JgRDCfAwfZHGzcwRn0jHXd
license: BSD3
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors
category: Data Structures, Adjunctions
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
abi: 1e1583bb7fdb392e25ed99584e968a7f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/adjunctions-4.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/adjunctions-4.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/adjunctions-4.3
hs-libraries: HSadjunctions-4.3-JgRDCfAwfZHGzcwRn0jHXd
depends:
    array-0.5.1.1 base-4.9.0.0 comonad-5-FocVP0xchqoELxW0q31ZBF
    containers-0.5.7.1 contravariant-1.4-QSyIMKSTFU5sk4KxSecCX
    distributive-0.5.2-SlRGCHnocy81GrFzDcKVs
    free-4.12.4-DZCTkfqdDiF4eKUVutuQ1W mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    profunctors-5.2-DDzWnW7PWEeEYRCGSjacrC
    semigroupoids-5.1-KBxlUMJdBcK6rKu26wa0Rl
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    void-0.7.1-7ItcNGyWY8l57cMz7KooSQ
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.3-26-i686.pkg.tar.xz: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.3
id: adjunctions-4.3-GHyMBM8SEvq1VNbtxToJES
key: adjunctions-4.3-GHyMBM8SEvq1VNbtxToJES
license: BSD3
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors
category: Data Structures, Adjunctions
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
abi: d73b9b09335eb54847298ae06c3e559b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/adjunctions-4.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/adjunctions-4.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/adjunctions-4.3
hs-libraries: HSadjunctions-4.3-GHyMBM8SEvq1VNbtxToJES
depends:
    array-0.5.1.1 base-4.9.0.0 comonad-5-IFpew4VeZSgJKPLIcHpKjC
    containers-0.5.7.1 contravariant-1.4-KgMYVwXYQBGKuyyJtYdP11
    distributive-0.5.2-SlRGCHnocy81GrFzDcKVs
    free-4.12.4-3djEuuVf78E7uL6ewIYMHB mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    profunctors-5.2-1HLm9WoKgF5GvKRjOhOJmS
    semigroupoids-5.1-mvlh42rhjC5vNXakyMT7n
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    void-0.7.2-Gq1uNTFl2JaJr51CTc0tGb
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
